Package 'mnedesigndata'

Title: Design data of the Monitoring Programme for the Natural Environment (MNE)
Description: mnedesigndata is an R package to distribute and document R data objects that reflect the current implementation design of the Monitoring Programme for the Natural Environment (MNE). Aspects are covered such as the scheme's spatial sampling frames, the spatiotemporal samples and the designed revisit patterns of the most important field activities. The objects originate particularly from the REP workflow (revisitplan) and scripts tied to it.
Authors: Floris Vanderhaeghe [aut, cre] (ORCID: <https://orcid.org/0000-0002-6378-6229>), Research Institute for Nature and Forest (INBO) [cph]
Maintainer: Floris Vanderhaeghe <[email protected]>
License: GPL (>= 3)
Version: 0.2.1
Built: 2026-05-20 17:01:49 UTC
Source: https://github.com/inbo/mnedesigndata

Help Index


Activities that support data collection directly or indirectly

Description

The data frame activities defines activities that support data collection in some essential way, either directly or indirectly.

Format

Data frame.

Details

Several attributes are given and not all categories are further used by the REP-workflow. The field activities are used in the REP to create the designed sampling unit calendar of field activity groups (fag_stratum_grts_calendar). Several other activities are used in fieldwork optimization steps outside of the REP.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activity_sequences, domains, mod_scheme_vars, module_domains, modules, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes, submodules


Activity sequences

Description

The data frame activity_sequences defines the available activity sequences. An activity sequence is a set of activities (from activities) that are tied together at location level for a specific scheme in a module, with a specific chronological order and a specific intent.

Format

Data frame.

Details

The intent of an activity sequence is to be seen in the context of a scheme in a module, and relates to data collection for one or more variables. An activity sequence may be used by different schemes, and a single scheme may combine more than one, since multiple variables are determined by a single scheme. Also, different activity sequences may apply to the same scheme depending on the module.

Some activities in an activity sequence may have different panel designs, due to the nature of the activity or other requirements or restrictions, so the frequency of some activities may be higher but the overall chronology remains in place.

Note

Currently, activity_sequences is also the place where the activity groups are inherently defined (i.e. which activities they are composed of), although this is no logical place for this. The plan is to isolate that aspect so that activity_sequences can be replaced by an object activity_group_sequences.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, domains, mod_scheme_vars, module_domains, modules, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes, submodules


Spatial population sizes of strata in each domain

Description

The data frame domain_stratum_nunits contains the spatial population size of each stratum in each domain, without taking into account scheme-specific spatial restrictions.

Format

Data frame.

Details

domain_stratum_nunits is based on the collapsed & phab-corrected base sampling frame (stratum_grts_n2khab_phabcorrected_no_replacements). Hence it is scheme-agnostic, while some schemes need a more restricted sampling frame (see sp_samplingframes). For the final population sizes at submodule x domain x scheme level, see submod_dom_scheme_ssf_stratum_nunits.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects about spatial population size: domain_type_nunits, submod_dom_scheme_ssf_stratum_nunits, submodule_domain_scheme_stratumstats, submodule_domain_scheme_typestats


Spatial population sizes of types in each domain

Description

The data frame domain_type_nunits contains the spatial population size of each type in each domain, without taking into account scheme-specific spatial restrictions.

Format

Data frame.

Details

domain_type_nunits is derived from domain_stratum_nunits by simply aggregating strata that belong to the same type; see its documentation for more background, as well as submod_dom_scheme_ssf_stratum_nunits.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects about spatial population size: domain_stratum_nunits, submod_dom_scheme_ssf_stratum_nunits, submodule_domain_scheme_stratumstats, submodule_domain_scheme_typestats


Domain partition of each GRTS address in the base sampling frame

Description

The data frame domainpart_grts_n2khab classifies the GRTS addresses of the base sampling frame using the domain partition. Domain partitions are mutually exclusive in space, while domains (see domains) can spatially overlap.

Format

Data frame.

Details

The domain partition is used to uniquely characterize each GRTS address, preferring its membership to the smallest (innermost) domain it belongs to, whereas the remainder of the larger (including) domain is regarded as the domain partition labelled with suffix "_remainder".

Note that values of the domain_part column can also be based on domains that are not used to drive sampling.

domainpart_grts_n2khab is derived from the domain_grts_n2khab data frame, itself derived from domains and grts_mh_n2khab (= the GRTSmaster_habitats raster data source subsetted by the base sampling frame).

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops, targetpops_strata


Domains

Description

The sf object domains defines code, names and geometry of each geospatial domain that is targeted by a module (see module_domains).

Format

A simple feature collection of type MULTIPOLYGON.

Details

With the term 'domain' we always refer to a geospatial domain listed in this object.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, mod_scheme_vars, module_domains, modules, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes, submodules


Designed fieldwork calendar

Description

The data frame fag_stratum_grts_calendar represents the designed sampling unit calendar – across schemes – of the distinguished field activity groups (FAGs). It has unique combinations of stratum, grts_address, date_interval and field_activity_group.

Format

Data frame.

Details

fag_stratum_grts_calendar is derived from the scheme-specific FAG calendars (object scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar) by eliminating spatiotemporal duplication and taking into account the highest required FAG frequency across schemes.

fag_stratum_grts_calendar can have extensions included, i.e. appended FAG occasions according to older fag_stratum_grts_calendar versions, i.e. from older REP versions. This subset can be seen by inspecting the object cal_old_continuation. Some of these rows may even concern spatial sampling units that are missing from the current spatiotemporal samples, but for which selected field activity groups (FAGs) and occasions have been retained. The appended FAG occasions can only be applied in reality if the preceding FAG occasions on which they depend (not included) have already taken place, i.e. in the context of a previous REP release.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects of the design outcome: scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar, scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar, scheme_moco_ps_stratum_sppost_spsamples, scheme_moco_ps_stratum_sppost_spsamples_spares


Designed short-term fieldwork calendar with extra attributes

Description

The data frame fieldwork_shortterm_prioritization_by_stratum is an extract from fag_stratum_grts_calendar and has extra attribute columns. The aim is to provide the input needed for shortterm fieldwork planning and prioritization, based on the designed revisit pattern of the most important field activities. For that reason, it has the priority and wait_xxx columns.

Format

Data frame.

Details

The is_forest, in_mhq_samples and last_type_assessment_in_field columns are given because they drive subsampling locations in cell-based sampling units.

The dates of early "LOCEVAL"-containing field activity groups may have been edited (postponed) compared to fag_stratum_grts_calendar.

Fields

scheme_ps_targetpanels

Factor. A concatenation of "{scheme}:PS{panel set number}{targetpanel}" strings, separated by " | " in case more than one targetpanel applies. It represents the different targetpanels (each belonging to a scheme and panel set) for which this field activity group in the specified spatial sampling unit needs to be done in the specified date interval as it cannot be delayed for the data collection in this targetpanel. For field activity group (FAG) occasions and spatial sampling units that do not correspond to the current spatiotemporal samples (see scheme_ps_oldtargetpanels), the value of scheme_ps_oldtargetpanels is used instead. This is done to avoid missing values in derived objects or overviews.

schemes_served_all

Factor. A concatenation of schemes, separated by "|", that will make use of this scheduled field activity group (FAG) in the specified spatial sampling unit. It includes the schemes mentioned in scheme_ps_targetpanels but it can have more: in other schemes this FAG would have been scheduled at a later time, but they can and will use this FAG occasion instead.

nr_schemes_current

Integer. The number of schemes that have scheduled this field activity group in the specified spatial sampling unit in the specified date interval.

nr_schemes_later

Integer. The number of schemes that originally scheduled this field activity group in the specified spatial sampling unit in a later date interval, but that will be using this occasion instead.

stratum

Factor. A type or a subdivision thereof, used in the stratified sampling design and inference. Defined by the n2khab_strata data frame.

grts_join_method

Factor. The method that has served to assign a GRTS address to the sampling unit.

sample_support_code

Factor. Code that reflects the sample support, i.e. geometric properties (size, shape, orientation) that define the sampling unit. The sample support depends on the type (hence on stratum).

grts_address

Integer. The GRTS address from the GRTSmaster_habitats data source that has been drawn when creating the sample. grts_address and stratum together identify the spatial sampling unit.

grts_address_final

Integer. The GRTS address from the GRTSmaster_habitats data source that has been used as a local replacement for grts_address, given the stratum. Its role is to point at the final location for data collection. grts_address_final remains tied to grts_address and stratum, that identify the spatial sampling unit. (grts_address_final can also be regarded as a secondary sampling unit within a larger primary sampling unit determined by grts_address and stratum.)

domain_part

Factor. The domain partition to which the spatial sampling unit belongs.

is_forest

Logical. Does the stratum correspond to a forest type? Forest types are defined using the regex "^9|^2180|^rbbppm".

in_mhq_samples

Logical. Is the sampling unit also a member of a spatial sample of MHQ (at the Flemish level)?

last_type_assessment_in_field

Logical. Did the sampling unit get a field assessment in the past as part of MHQ (at the Flemish level)?

last_type_assessment

Date. Latest available MHQ field assessment date for the sampling unit in MHQ (at the Flemish level).

last_inaccessible

Factor. The degree of inaccessibility during the latest available MHQ field assessment for the sampling unit (MHQ at the Flemish level). Possible factor levels (if not missing) are "short term" and "long term", reflecting an estimated duration of inaccessibility.

scheme_ps_oldtargetpanels

Factor. A string formatted as and with a meaning similar to scheme_ps_targetpanels but according to older versions of the REP. Most rows have a missing value, but rows with a value refer to a part of fag_stratum_grts_calendar from an older REP version that has been appended to the current version. Some of these rows may even concern spatial sampling units that are missing from the current spatiotemporal samples, for which selected field activity groups (FAGs) and occasions have been retained. The appended FAG occasions can only be applied in reality if the preceding FAG occasions on which they depend (not included) have already taken place, i.e. in the context of a previous release of the short-term fieldwork calendar.

date_start

Date. Start of the date interval during which the field activity group is scheduled in the spatial sampling unit.

date_end

Date. End of the date interval during which the field activity group is scheduled in the spatial sampling unit.

date_interval

Interval. The date interval during which the field activity group is scheduled in the spatial sampling unit.

field_activity_group

Factor. A defined group of field activities. Many field activity groups consist of just one field activity.

rank

Integer. A rank number representing the order of execution relative to other field activity groups that are scheduled in the same date interval, for the same spatial sampling unit. This rank has originally been defined within an activity sequence that was assigned to the spatial sampling unit in the context of a specific module and scheme.

priority

Integer. A rank number representing the priority of the scheduled field activity group for the specified spatial sampling unit.

wait_any

Logical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold? This column is TRUE if any of the other wait columns is TRUE.

wait_watersurface

Logical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold because the sampling unit is a watersurface? Watersurface types are defined using the regex "^31|^2190_a".

wait_3260

Logical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold because the sampling unit belongs to type 3260?

wait_7220

Logical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold because the sampling unit belongs to type 7220?

wait_floating

Logical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold because the sampling unit belongs to a floating (fen) type? Currently this is defined as type ⁠7140_mrd⁠.

wait_mhq

Logical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold because in the considered date interval (year) the field activity group is only needed for a MHQ scheme? (The latter is seen in the value of scheme_ps_targetpanels.)

wait_obsolete_types

Logical. Should the scheduled field activity group in the specified spatial sampling unit be put on hold because the type will be obsoleted and this makes this FAG occasion in this panel set irrelevant?

The code snippets file, which creates objects derived from REP objects. See https://github.com/inbo/n2khab-mne-monitoring/blob/main/020_fieldwork_organization/code_snippets.R.


Field activities and field activity groups per module, scheme & spatial subset

Description

The data frame mod_scheme_field_activity contains all field activities and associated field activity groups (FAGs) for each activity sequence in a module x scheme x spatial subset.

Format

Data frame.

Details

mod_scheme_field_activity (indirectly) builds on mod_scheme_variableset_mainfieldactivity, activity_sequences and properties of the target populations.

Spatial subset XXXXXXXXXXXXXX

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The spatial subset is used in multiple objects and currently only concerns the distinction between aquatic and terrestrial strata (column in_aquatic_subset). It is relevant to determine the applicable activity sequence (i.e. for involved field activity groups).

Restriction by domains and sampling frames

This object has been further restricted by module_domain_schemes. This means that the current spatial distribution of target populations of the module's schemes within the module's domain(s) is taken into account, using the scheme's spatial sampling frame. When the domains of a module represent a relatively small area, it is possible:

  • for target populations: that some types (that were initially targeted by the module) are not present in that area and consequently dropped from the module's target populations

  • for schemes: that some schemes targeted by the module are not applicable, i.e. when no types of its target population are present in that area

Also, note that for MHQ schemes, module_domain_schemes only considers – on a domain basis – the schemes with sampling approaches, not the census approaches, and this also leads to a further restriction.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops, targetpops_strata


Panel design of field activity groups per module x scheme x panel set x spatial subset

Description

The data frame mod_scheme_ps_fag_paneldesign defines the panel design of each field activity group per module x scheme x panel set x spatial subset.

Format

Data frame.

Details

mod_scheme_ps_fag_paneldesign (indirectly) uses mod_scheme_field_activity as its base, but with collapsed activity sequences: field activity groups shared among multiple activity sequences (in the same module, scheme and spatial subset) appear only once.

Spatial subset XXXXXXXXXXXXXX

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The spatial subset is used in multiple objects and currently only concerns the distinction between aquatic and terrestrial strata (column in_aquatic_subset). It is relevant to determine the applicable activity sequence (i.e. for involved field activity groups).

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects with design attributes: mod_scheme_yrs_moco_ps, module_domain_scheme_ps_stratum_sample_size, scheme_ps_target_paneldesign, scheme_ps_variableset_paneldesign, submodule_domain_scheme_ps_designattr


Target field activities per module and scheme

Description

The data frame mod_scheme_targetfieldactivity contains the main field activities that are related to the target variable(s) of a module and scheme: the so-called 'target field activities'.

Format

Data frame.

Details

mod_scheme_targetfieldactivity is indirectly derived from mod_scheme_variableset_mainfieldactivity.

Restriction by domains and sampling frames

This object has been further restricted by module_domain_schemes. This means that the current spatial distribution of target populations of the module's schemes within the module's domain(s) is taken into account, using the scheme's spatial sampling frame. When the domains of a module represent a relatively small area, it is possible:

  • for target populations: that some types (that were initially targeted by the module) are not present in that area and consequently dropped from the module's target populations

  • for schemes: that some schemes targeted by the module are not applicable, i.e. when no types of its target population are present in that area

Also, note that for MHQ schemes, module_domain_schemes only considers – on a domain basis – the schemes with sampling approaches, not the census approaches, and this also leads to a further restriction.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops, targetpops_strata


Main field activities per module and scheme

Description

The data frame mod_scheme_variableset_mainfieldactivity contains just the main data collection methods from mod_scheme_vars that are field activities, which are now renamed as 'main field activities'. In addition, it contains the main field activities for MHQ schemes.

Format

Data frame.

Details

Note that MHQ schemes are not considered in mod_scheme_vars, which is focused on MNE, but their associated activities are supported by activities and activity_sequences.

Note that the terms 'main data collection method' and 'main field activity' are to be understood from the viewpoint of a variable (variable set) in a module:scheme combination; it is not about the 'main method' of the module:scheme combination. In consequence, multiple 'main field activities' can be linked to a module:scheme combination, and they may come from target variables and other variables as well.

Restriction by domains and sampling frames

This object has been further restricted by module_domain_schemes. This means that the current spatial distribution of target populations of the module's schemes within the module's domain(s) is taken into account, using the scheme's spatial sampling frame. When the domains of a module represent a relatively small area, it is possible:

  • for target populations: that some types (that were initially targeted by the module) are not present in that area and consequently dropped from the module's target populations

  • for schemes: that some schemes targeted by the module are not applicable, i.e. when no types of its target population are present in that area

Also, note that for MHQ schemes, module_domain_schemes only considers – on a domain basis – the schemes with sampling approaches, not the census approaches, and this also leads to a further restriction.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, module_domain_schemes, module_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops, targetpops_strata


Variables and measurement variables

Description

The data frame mod_scheme_vars defines variables (usually environmental variables) per module and (MNE) scheme, as well the associated measurement variable (if the variable is directly based on measurements). Also, the target site factor is given for which the variable serves a role in the module and scheme. Further, multiple attributes are given that characterize the variable in the context of the module and the scheme.

Format

Data frame.

Details

The measurement variable may be different from the environmental variable when the latter is defined by aggregating multiple measurements to obtain one value for the spatiotemporal sampling unit.

In the context of a module and (especially) a scheme, variables can be qualified as 'target variables' (aka primary environmental variables), 'explanatory variables' or 'quality control variables'. A variable sometimes belongs to more than one of these categories.

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The main data collection method represents the activity that is considered most essential (most specific) for the data collection in the spatial or spatiotemporal sampling unit. It must be an activity from the activities object.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, module_domains, modules, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes, submodules


Relation between module x scheme x panel set and module combos

Description

The data frame mod_scheme_yrs_moco_ps is a simple object with the link between modules and module combos per scheme x panel set.

Format

Data frame.

Details

mod_scheme_yrs_moco_ps is derived from scheme_ps_target_paneldesign and module_domain_scheme_ps_stratum_sample_size.

Compared to scheme_ps_target_paneldesign, mod_scheme_yrs_moco_ps no longer covers the non-core schemes, except if a type had been additionally adopted for such a scheme (see module_domain_scheme_ps_stratum_sample_size).

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects with design attributes: mod_scheme_ps_fag_paneldesign, module_domain_scheme_ps_stratum_sample_size, scheme_ps_target_paneldesign, scheme_ps_variableset_paneldesign, submodule_domain_scheme_ps_designattr


Spatial sample sizes of strata per module x domain x scheme x panel set

Description

The data frame module_domain_scheme_ps_stratum_sample_size contains the spatial sample size per stratum in each module x domain x scheme x panel set.

Format

Data frame.

Details

module_domain_scheme_ps_stratum_sample_size plays a key role in the spatial sampling procedure. It is derived from submodule_domain_scheme_ps_designattr, it no longer distinguishes between submodules (see submodules) and takes into account finite population correction.

Note

This object still has the full target population for each module x domain x scheme in the case of non-core schemes, but the sample sizes will generally be missing values since they are not designed: only the locations that are common between the sample of a related core scheme and the sampling frame of the non-core scheme can be attributed to the non-core scheme (insofar the core scheme schedules data collection that makes sense to the non-core scheme target variables). So this sample can be a subset of the sample of the core scheme. Since it causes no extra fieldwork, we don't explicitly consider these sample sizes and samples. (There's still an exception possible: we exceptionally attribute an extra sample size in non-core MNE schemes in order to adopt an extra type (which must belong to the non-core scheme's target population) that is not covered by a corresponding core MNE scheme, if it makes an important difference to that non-core scheme.)

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects with design attributes: mod_scheme_ps_fag_paneldesign, mod_scheme_yrs_moco_ps, scheme_ps_target_paneldesign, scheme_ps_variableset_paneldesign, submodule_domain_scheme_ps_designattr


Schemes per module x domain, taking into account the sampling frames

Description

The data frame module_domain_schemes lists the schemes that apply to each domain in each module, according to the presence of strata in domains, hence according to the sampling frames.

Format

Data frame.

Details

For MHQ schemes, module_domain_schemes only considers – on a domain basis – the schemes with sampling approaches, not the census approaches, and this also leads to a further restriction.

module_domain_schemes is derived from submod_dom_scheme_ssf_stratum_nunits, which is in turn derived from scheme_sampling_frame, sp_samplingframe_domain and a few other objects (see there).

module_domain_schemes has been used to limit several module:scheme objects that had been made before, such as module_schemes, module_targetpops, mod_scheme_variableset_mainfieldactivity, mod_scheme_field_activity, mod_scheme_ps_fag_paneldesign.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops, targetpops_strata


Domains per module

Description

The data frame module_domains defines which geospatial domains are targeted by each module.

Format

Data frame.

Details

For the domains, see domains; for the modules, see modules.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, mod_scheme_vars, modules, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes, submodules


Schemes per module

Description

The data frame module_schemes lists the schemes of each module. It is derived from submodules and scheme_targetpop_sets.

Format

Data frame.

Restriction by domains and sampling frames

This object has been further restricted by module_domain_schemes. This means that the current spatial distribution of target populations of the module's schemes within the module's domain(s) is taken into account, using the scheme's spatial sampling frame. When the domains of a module represent a relatively small area, it is possible:

  • for target populations: that some types (that were initially targeted by the module) are not present in that area and consequently dropped from the module's target populations

  • for schemes: that some schemes targeted by the module are not applicable, i.e. when no types of its target population are present in that area

Also, note that for MHQ schemes, module_domain_schemes only considers – on a domain basis – the schemes with sampling approaches, not the census approaches, and this also leads to a further restriction.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops, targetpops_strata


Target populations per module

Description

The data frame module_targetpops lists the target populations of each module at type level. It is derived from submodules and scheme_targetpop_sets.

Format

Data frame.

Restriction by domains and sampling frames

This object has been further restricted by module_domain_schemes. This means that the current spatial distribution of target populations of the module's schemes within the module's domain(s) is taken into account, using the scheme's spatial sampling frame. When the domains of a module represent a relatively small area, it is possible:

  • for target populations: that some types (that were initially targeted by the module) are not present in that area and consequently dropped from the module's target populations

  • for schemes: that some schemes targeted by the module are not applicable, i.e. when no types of its target population are present in that area

Also, note that for MHQ schemes, module_domain_schemes only considers – on a domain basis – the schemes with sampling approaches, not the census approaches, and this also leads to a further restriction.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, schemes, sp_samplingframe_domain, targetpops, targetpops_strata


Modules

Description

The data frame modules defines the modules, their names, shortnames and codes, as well as several temporal attributes.

Format

Data frame.

Details

A module is like a project, that aims at realizing some well-defined part of MNE + MHQ. It determines which schemes, which domains and which part of the target populations are in scope for the module. For the schemes and target populations this happens indirectly via submodules; for the domains this is via module_domains.

Several objects with scheme properties have a module column to make these properties module-dependent.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, mod_scheme_vars, module_domains, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes, submodules


Strata for sampling and inference

Description

The data frame n2khab_strata defines the stratum levels available in the stratum column of the spatial sampling frames (see sp_samplingframes, scheme_sampling_frame). Also, the data frame defines the link between type and stratum.

Format

Data frame.

Details

The strata are used in spatial sampling and inference. They are either a type or a subdivision thereoff. The latter applies to watersurface types (type regex "^31|^2190_a") and to type 8310.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, mod_scheme_vars, module_domains, modules, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes, submodules


Designed fieldwork calendar per scheme x module combo x panel set x spatial poststratum

Description

The data frame scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar represents the designed sampling unit calendar of the distinguished field activity groups (FAGs), after cleaning within, but not between, levels of scheme x module combo x panel set x spatial poststratum.

Format

Data frame.

Details

scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar combines the panel calendar and the panel memberships generated in the REP workflow, which have been (indirectly) based on mod_scheme_ps_fag_paneldesign and scheme_moco_ps_stratum_sppost_spsamples. Panels and FAG occasions have been dropped if the scheduled calendar starts at a later point in time. Also some superfluous occasions of specific auxiliary FAGs have been dropped.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects of the design outcome: fag_stratum_grts_calendar, scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar, scheme_moco_ps_stratum_sppost_spsamples, scheme_moco_ps_stratum_sppost_spsamples_spares


Spatiotemporal samples

Description

The data frame scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar represents the (planned) spatiotemporal samples per scheme x module combo x panel set x spatial poststratum.

Format

Data frame.

Details

scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar is the subset of scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar that only contains the target field activity groups (based on mod_scheme_targetfieldactivity). The corresponding panel labels have been simplified in the targetpanel column: 'targetpanels' are the panels of target FAGs, cf. scheme_ps_target_paneldesign.

The spatiotemporal samples are not further used in the REP workflow, but the object can be useful to add some attributes to FAG occasions from fag_stratum_grts_calendar, such as the involved scheme, module combo, panel set and targetpanel. This has been done in the 'code snippets' (e.g. fieldwork_shortterm_prioritization_by_stratum).

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects of the design outcome: fag_stratum_grts_calendar, scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar, scheme_moco_ps_stratum_sppost_spsamples, scheme_moco_ps_stratum_sppost_spsamples_spares


Spatial samples

Description

The data frame scheme_moco_ps_stratum_sppost_spsamples contains the spatial samples per stratum, for each scheme x panel set x module combo.

Format

Data frame.

Details

scheme_moco_ps_stratum_sppost_spsamples is like scheme_moco_ps_stratum_sppost_spsamples_spares without the spare units.

Note that spatial samples typically overlap between schemes, i.e. where the scheme's target populations overlap.

Sample column notes

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX

  • grts_address and stratum together identify the spatial sampling unit. See further in fieldwork_shortterm_prioritization_by_stratum.

  • The spatial poststratum (sp_poststratum) serves to add spare units and to apply the revisit design (notably the panel membership design): it is based on the domain overlaps between modules in a module combo for a specific stratum in a scheme x panel set, so it is not an overall predetermined classification but a 'classification as needed'. It takes values of domains as well as the complement of overlapped smaller domains by using the suffix '_remainder', e.g. 'Flanders_remainder'. Don't use sp_poststratum to just characterize a GRTS address. If you need a fixed spatial partitioning across strata and schemes, make a join with domainpart_grts_n2khab, where the 'domain partition' only represents areas that are mutually exclusive in space.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects of the design outcome: fag_stratum_grts_calendar, scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar, scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar, scheme_moco_ps_stratum_sppost_spsamples_spares


Spatial samples plus spare sampling units

Description

The data frame scheme_moco_ps_stratum_sppost_spsamples_spares contains the spatial samples plus the spare units per stratum, for each scheme x panel set x module combo.

Format

Data frame.

Details

scheme_moco_ps_stratum_sppost_spsamples_spares is the first result of the spatial sampling procedure that distinguishes the spatial poststrata.

Note that spatial samples typically overlap between schemes, i.e. where the scheme's target populations overlap.

Sample column notes

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX

  • grts_address and stratum together identify the spatial sampling unit. See further in fieldwork_shortterm_prioritization_by_stratum.

  • The spatial poststratum (sp_poststratum) serves to add spare units and to apply the revisit design (notably the panel membership design): it is based on the domain overlaps between modules in a module combo for a specific stratum in a scheme x panel set, so it is not an overall predetermined classification but a 'classification as needed'. It takes values of domains as well as the complement of overlapped smaller domains by using the suffix '_remainder', e.g. 'Flanders_remainder'. Don't use sp_poststratum to just characterize a GRTS address. If you need a fixed spatial partitioning across strata and schemes, make a join with domainpart_grts_n2khab, where the 'domain partition' only represents areas that are mutually exclusive in space.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects of the design outcome: fag_stratum_grts_calendar, scheme_moco_ps_spsubset_fag_stratum_sppost_spsamples_calendar, scheme_moco_ps_spsubset_targetfag_stratum_sppost_spsamples_calendar, scheme_moco_ps_stratum_sppost_spsamples


Target panel designs per scheme x panel set x module combo

Description

The data frame scheme_ps_target_paneldesign contains only the panel designs (from mod_scheme_ps_fag_paneldesign) for the so called 'target field activity groups' (target FAGs), i.e. the FAGs containing the target field activity (see mod_scheme_targetfieldactivity). These panel designs can be called target panel designs and the corresponding panels will be called 'targetpanels'. Importantly, the module level is gone: instead, modules with the same target panel design are combined as 'module combos' at the scheme x panel set level.

Format

Data frame.

Details

scheme_ps_target_paneldesign is derived from mod_scheme_targetfieldactivity, mod_scheme_ps_fag_paneldesign and mod_scheme_field_activity (to link field activity and field activity groups).

The target variables limit the main field activities of a module x scheme to a great extent, since the latter also comprise variables for explanation & quality control. (Remember: the term 'main field activity' is to be understood from the viewpoint of a variable (set) in a module x scheme, not just the module x scheme; see mod_scheme_variableset_mainfieldactivity.)

For each scheme x panel set, the modules (in mod_scheme_ps_fag_paneldesign) have been collapsed to module combos (module combinations) if the corresponding target panel design is the same.

  • So, beware that the module combo can only be interpreted as a unique panel design in combination with scheme x panel set.

  • scheme_ps_target_paneldesign is the object in the REP-workflow where the module combos are effectively generated and defined.

  • However, see the derived data frame mod_scheme_yrs_moco_ps for a convenient object that links modules and module combos within scheme x panel set.

  • The concept of module combos is important to the spatial sampling procedure: spatial sampling for a scheme x panel set is to be combined over active modules when their target panel design and domain is the same. Also with overlapping domains, the sampling procedure must take into account the relation between the samples from both domains.

Note that the 'spatial subset' from mod_scheme_ps_fag_paneldesign is gone. That is because for the main field activities the spatial subsets don't have differences in the corresponding panel designs.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects with design attributes: mod_scheme_ps_fag_paneldesign, mod_scheme_yrs_moco_ps, module_domain_scheme_ps_stratum_sample_size, scheme_ps_variableset_paneldesign, submodule_domain_scheme_ps_designattr


Panel designs of measurements (data occurrence) per scheme x panel set

Description

The data frame scheme_ps_variableset_paneldesign contains the panel design of measurements at the level of a variable set in a scheme x panel set. With 'measurements' we mean the data occurrence, not the human activity. The associated 'main field activity' is included though to make clear how the data are collected. All variables are covered, so this is different from the scope of scheme_ps_target_paneldesign, where only the 'target field activities' (main field activities for target variables) are considered.

Format

Data frame.

Details

scheme_ps_variableset_paneldesign has statistical relevance and it is (should be) in line with relevant parts of mod_scheme_ps_fag_paneldesign, but it is not used further in the REP workflow.

scheme_ps_variableset_paneldesign uses mod_scheme_variableset_mainfieldactivity as its base.

Notable differences with mod_scheme_ps_fag_paneldesign are that:

  • automated frequent measurements are reflected as 'frequent revisit' while fieldwork is much less frequent;

  • currently no distinction between modules is made;

  • only core schemes are considered;

  • no installation or maintenance is involved, since those are not main field activities (for a variable set).

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects with design attributes: mod_scheme_ps_fag_paneldesign, mod_scheme_yrs_moco_ps, module_domain_scheme_ps_stratum_sample_size, scheme_ps_target_paneldesign, submodule_domain_scheme_ps_designattr


Spatial sampling frames by scheme

Description

The data frame scheme_sampling_frame defines which spatial sampling frame from sp_samplingframes should be further processed to use in a specific scheme.

Format

Data frame.

Details

See sp_samplingframes for more information.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, mod_scheme_vars, module_domains, modules, n2khab_strata, scheme_targetpop_sets, sp_samplingframes, submodules


Named sets of schemes with target populations

Description

The data frame scheme_targetpop_sets defines different collections of schemes with associated target populations. Each submodule in the submodules object refers to a single 'scheme + target population set', i.e. to one row of this data frame.

Format

Data frame.

Details

The target populations are given at type level and at stratum level. The stratum level target population follows from the type level, as all strata of each involved type are included.

These target populations cannot exceed the target populations defined by n2khabmon::read_scheme_types(), but they can be subsets considered by a specific (sub)module, which is their true aim.

Note that scheme_targetpop_sets can list more sets than actually used by the active modules and submodules.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, mod_scheme_vars, module_domains, modules, n2khab_strata, scheme_sampling_frame, sp_samplingframes, submodules


All schemes considered by scheme_targetpop_sets

Description

The data frame schemes contains the schemes listed by at least one 'scheme + target population set' of the scheme_targetpop_sets object.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, module_targetpops, sp_samplingframe_domain, targetpops, targetpops_strata


Spatial sampling frames with a domain attribute

Description

The data frame sp_samplingframe_domain is no more than the data frame sp_samplingframes where each sampling frame has been extended with a domain column. Since domains can overlap, joining the spatial population units with the applicable domain(s) has generated duplicates of many units in this object.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, module_targetpops, schemes, targetpops, targetpops_strata


Spatial sampling frames

Description

The data frame sp_samplingframes defines spatial sampling frames that can be shared among different schemes and modules, but which are generally still 'too large' for a specific scheme in a specific module. The object scheme_sampling_frame defines which spatial sampling frame should be further processed for use in a specific scheme.

Format

Data frame.

Details

These spatial sampling frames are the result of applying some special spatial restrictions to the base sampling frame as implied by n2khabmon::read_scheme_types(). To obtain the ultimate spatial sampling frame for a specific scheme in a specific module, these sampling frames must still be subsetted using the target population and domain implied by a scheme in a module. A summarized result of that final step can be found in submod_dom_scheme_ssf_stratum_nunits.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, mod_scheme_vars, module_domains, modules, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, submodules


Spatial population sizes of strata at submodule x domain x scheme level

Description

The data frame submod_dom_scheme_ssf_stratum_nunits contains the spatial population size of each stratum in each submodule x domain x scheme.

Format

Data frame.

Details

submod_dom_scheme_ssf_stratum_nunits is based on scheme_sampling_frame, sp_samplingframe_domain, scheme_targetpop_sets, submodules and module_domains. Its main application is the finite population correction.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects about spatial population size: domain_stratum_nunits, domain_type_nunits, submodule_domain_scheme_stratumstats, submodule_domain_scheme_typestats


Spatiotemporal design attributes per submodule x domain x scheme x panel set

Description

The data frame submodule_domain_scheme_ps_designattr contains the spatiotemporal design attributes per submodule x domain x scheme x panel set.

Format

Data frame.

Details

submodule_domain_scheme_ps_designattr is the last stage in the REP workflow where submodules are being distinguished; in determining stratum level sample sizes (see module_domain_scheme_ps_stratum_sample_size) the sample sizes of the submodules of each module are taken together (see submodules).

XXXXXX Omit once columns have been described: XXXXXXXXXXXXXXXX The spatial sample sizes refer to the submodule x domain x scheme x panel set level (sp_sample_size_all_panels) and to the level of a single (generalized) type (sp_sample_size_all_panels_type) within submodule x domain x scheme x panel set, respectively.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects with design attributes: mod_scheme_ps_fag_paneldesign, mod_scheme_yrs_moco_ps, module_domain_scheme_ps_stratum_sample_size, scheme_ps_target_paneldesign, scheme_ps_variableset_paneldesign


Stratum population size summary statistics per submodule x domain x scheme

Description

The data frame submodule_domain_scheme_stratumstats contains stratum counts and spatial population size ranges and quartiles for each submodule x domain x scheme.

Format

Data frame.

Details

submodule_domain_scheme_stratumstats is an aggregation based on submod_dom_scheme_ssf_stratum_nunits. It is used in the spatiotemporal design attributes (submodule_domain_scheme_ps_designattr).

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects about spatial population size: domain_stratum_nunits, domain_type_nunits, submod_dom_scheme_ssf_stratum_nunits, submodule_domain_scheme_typestats


Type population size summary statistics per submodule x domain x scheme

Description

The data frame submodule_domain_scheme_typestats contains type counts and spatial population size ranges and quartiles for each submodule x domain x scheme.

Format

Data frame.

Details

submodule_domain_scheme_typestats is an aggregation based on submod_dom_scheme_ssf_stratum_nunits. It is used in the spatiotemporal design attributes (submodule_domain_scheme_ps_designattr).

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other REP objects about spatial population size: domain_stratum_nunits, domain_type_nunits, submod_dom_scheme_ssf_stratum_nunits, submodule_domain_scheme_stratumstats


Submodules, with a set of schemes and target populations

Description

The data frame submodules defines the submodules of each module. Each submodule is strictly linked to a set of schemes and associated target populations.

Format

Data frame.

Details

The submodule name is only unique within a module. Each module has at least a single submodule, typically the submodule 'main'. With only a single submodule 'main' in place, the role of a submodule is trivial.

More submodules can exist in the same module, and these open the possibility to differentially extend the spatial sample of the main submodule. This means that some strata get extra locations than others, and other strata may be neglected in the submodule, meaning that the scheme + target population set may be smaller than the one at the module level. Put more generally, submodules differ in their scheme + target population set but together they represent the scheme + target population set of the module.

Submodules of the same module serve to contribute a part of the spatial sample size of each stratum in a module x scheme x domain, via submodule_domain_scheme_ps_designattr.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other defining REP objects: activities, activity_sequences, domains, mod_scheme_vars, module_domains, modules, n2khab_strata, scheme_sampling_frame, scheme_targetpop_sets, sp_samplingframes


All target populations considered by scheme_targetpop_sets, at type level

Description

The data frame targetpops contains the target populations (at type level) listed by at least one 'scheme + target population set' of the scheme_targetpop_sets object.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops_strata


All target populations considered by scheme_targetpop_sets, at stratum level

Description

The data frame targetpops_strata contains the target populations (at stratum level) listed by at least one 'scheme + target population set' of the scheme_targetpop_sets object.

Format

Data frame.

The REP (revisitplan) workflow. See https://github.com/inbo/n2khab-mne-designs/tree/revisitplan/100_design_common/010_revisitplan.

See Also

Other derivatives of defining REP objects: domainpart_grts_n2khab, mod_scheme_field_activity, mod_scheme_targetfieldactivity, mod_scheme_variableset_mainfieldactivity, module_domain_schemes, module_schemes, module_targetpops, schemes, sp_samplingframe_domain, targetpops